package com.gct.tool.entity.centralbase;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * <p>
 * 单井基础信息
 * </p>
 *
 * @author wsy
 * @since 2021-01-19
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@ApiModel(value="CbCdWellSource对象", description="单井基础信息")
@TableName("centralbase.cb_cd_well_source")
public class CbCdWellSource extends Model<CbCdWellSource> {

    private static final long serialVersionUID=1L;

    @ApiModelProperty(value = "井id")
    private String wellId;

    @ApiModelProperty(value = "通用井名")
    private String wellCommonName;

    @ApiModelProperty(value = "标准井名")
    private String wellLegalName;

    @ApiModelProperty(value = "井型")
    private String reason;

    @ApiModelProperty(value = "井别")
    private String wellPurpose;

    @ApiModelProperty(value = "投产措施;投产措施;0：无措施正常投产，1：压力投产，2：酸化投产")
    private Integer pStartProdStitum;

    @ApiModelProperty(value = "目的层")
    private String targetFormation;

    @ApiModelProperty(value = "开钻日期;钻井日期")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss" , timezone = "GMT+8")
    private LocalDateTime spudDate;

    @ApiModelProperty(value = "机构ID;井所属的组织机构ID")
    private String orgId;

    @ApiModelProperty(value = "构造单元ID;井所属的构造单元ID")
    private String structId;

    @ApiModelProperty(value = "油气单元ID;井所属的油气单元ID")
    private String oilfieldId;

    @ApiModelProperty(value = "物探工区ID;井所属的物探工区ID")
    private String expAreaId;

    @ApiModelProperty(value = "组合单元ID")
    private String groupUnitId;

    @ApiModelProperty(value = "站库ID")
    private String stationId;

    @ApiModelProperty(value = "纬度")
    private Double geoLatitude;

    @ApiModelProperty(value = "经度")
    private Double geoLongitude;

    @ApiModelProperty(value = "坐标参照")
    private String geoOffsetReference;

    @ApiModelProperty(value = "横坐标;向东偏离位置，对应大地坐标Y")
    private Double geoOffsetEast;

    @ApiModelProperty(value = "纵坐标;向北偏离位置，对应大地坐标X")
    private Double geoOffsetNorth;

    @ApiModelProperty(value = "备注")
    private String remarks;

    @ApiModelProperty(value = "是否是斜井，填写Y或N")
    private String isDeviated;

    @ApiModelProperty(value = "井身质量")
    private String endStatus;

    @ApiModelProperty(value = "生产层段名称")
    private String completionName;

    @ApiModelProperty(value = "生产区块名称")
    @TableField("PRODUCING_AREA_name")
    private String producingAreaName;

    @ApiModelProperty(value = "生产层段顶部垂深")
    private Double topTvd;

    @ApiModelProperty(value = "生产层段底部垂深")
    private Double bottomTvd;

    @ApiModelProperty(value = "完井层位ID")
    private String completionId;

    @ApiModelProperty(value = "井站名称|站库名称")
    private String stationName;


    @Override
    protected Serializable pkVal() {
        return null;
    }

}
